# Chatbot Database Structure

This project implements a chatbot that can interact with users and provide information about the structure of a database. The chatbot is designed to be easy to use and requires minimal coding knowledge to operate.

## Project Structure

```
chatbot-db-structure
├── src
│   ├── main.py               # Entry point of the application
│   ├── chatbot.py            # Contains the Chatbot class for managing conversations
│   ├── db
│   │   ├── __init__.py       # Initializes the db package
│   │   ├── connector.py       # Handles database connection
│   │   └── schema.py         # Retrieves and formats the database schema
│   └── utils
│       └── helpers.py        # Utility functions for various tasks
├── requirements.txt          # Lists project dependencies
├── .env.example              # Example environment variables
└── README.md                 # Documentation for the project
```

## Setup Instructions

1. Clone the repository:
   ```
   git clone <repository-url>
   cd chatbot-db-structure
   ```

2. Create a virtual environment:
   ```
   python -m venv venv
   ```

3. Activate the virtual environment:
   - On Windows:
     ```
     venv\Scripts\activate
     ```
   - On macOS/Linux:
     ```
     source venv/bin/activate
     ```

4. Install the required dependencies:
   ```
   pip install -r requirements.txt
   ```

5. Configure your environment variables by copying `.env.example` to `.env` and filling in the necessary values.

## Usage

To start the chatbot, run the following command:
```
python src/main.py
```

Once the chatbot is running, you can ask questions about the database structure, and it will respond with relevant information.

## Capabilities

- Provides information about the database schema, including tables and their columns.
- Allows users to interact naturally and receive structured responses.
- Designed to be extensible for future enhancements and additional features.

## Contributing

Contributions are welcome! Please feel free to submit a pull request or open an issue for any suggestions or improvements.